@@ -24,15 +24,15 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
 #ifndef __GTK_HSEPARATOR_H__
 #define __GTK_HSEPARATOR_H__
 
+#ifndef GTK_DISABLE_DEPRECATED
 
-#include <gdk/gdk.h>
 #include <gtk/gtkseparator.h>
 
 
@@ -66,4 +66,5 @@ GtkWidget* gtk_hseparator_new      (void);
 
 G_END_DECLS
 
+#endif
 #endif /* __GTK_HSEPARATOR_H__ */
