@@ -233,12 +233,12 @@ struct _GtkTextCursorDisplay
   guint is_strong : 1;
   guint is_weak : 1;
 };
+
 struct _GtkTextLineDisplay
 {
   PangoLayout *layout;
   GSList *cursors;
-  GSList *shaped_objects;	/* Only for backwards compatibility */
-  
+
   GtkTextDirection direction;
 
   gint width;                   /* Width of layout */
@@ -254,7 +254,6 @@ struct _GtkTextLineDisplay
   gint bottom_margin;
   gint insert_index;		/* Byte index of insert cursor within para or -1 */
 
-  gboolean size_only;
   GtkTextLine *line;
   
   GdkColor *pg_bg_color;
@@ -263,6 +262,9 @@ struct _GtkTextLineDisplay
   guint cursors_invalid : 1;
   guint has_block_cursor : 1;
   guint cursor_at_line_end : 1;
+  guint size_only : 1;
+
+  GdkRGBA *pg_bg_rgba;
 };
 
 #ifdef GTK_COMPILATION
